@@ -36,7 +36,7 @@ impl fmt::Display for IssueSeverity {
 
 impl IssueDefinition {
     /// This function checks a file content for the presence of an issue based on a regex.
-    /// These issues are defined using the IssueDefinition struct.
+    /// These issues are defined using the `IssueDefinition` struct.
     fn check(self, content: &str) -> Vec<IssueReport> {
         if self.multiline {
             let regex = RegexBuilder::new(self.pattern)
@@ -94,6 +94,8 @@ impl fmt::Display for IssueReport {
     }
 }
 
+/// The main validation function. Checks all possible issues in a single file, loaded from a file name.
+/// Prints the issues to the standard output.
 pub fn validate(file_name: &str) {
     debug!("Validating file `{}`", file_name);
 
@@ -121,7 +123,7 @@ pub fn validate(file_name: &str) {
             reports
         }
         // In the remaining cases, the file is a module, so test module requirements
-        _ => module::check(&content),
+        ModTypeOrReport::Type(_) => module::check(&content),
     };
 
     report_issues(reports, file_name);
@@ -129,14 +131,22 @@ pub fn validate(file_name: &str) {
 
 /// Print a sorted, human-readable report about the issues found in the file
 fn report_issues(mut issues: Vec<IssueReport>, file_path: &str) {
-    if !issues.is_empty() {
-        // Sort the reported issues by their line number
-        issues.sort_by_key(|report| report.line_number);
+    if issues.is_empty() {
+        // If there are no issues in the file, report that as info to avoid confusion over a blank output.
+        issues.push(IssueReport {
+            line_number: None,
+            description: "No issues found in this file.",
+            severity: IssueSeverity::Information,
+        });
+    }
 
-        println!("💾 File: {}", file_path);
-        for issue in issues {
-            println!("    {}", issue);
-        }
+    // Sort the reported issues by their line number
+    issues.sort_by_key(|report| report.line_number);
+
+    // Print the sorted reports for the file to the standard output
+    println!("💾 File: {}", file_path);
+    for issue in issues {
+        println!("    {}", issue);
     }
 }
 
@@ -149,15 +159,13 @@ enum ModTypeOrReport {
 
 /// Try to determine the module type of a file, using the file name and the file content.
 fn determine_mod_type(base_name: &str, content: &str) -> ModTypeOrReport {
-    if base_name.starts_with("assembly_") || base_name.starts_with("assembly-") {
-        return ModTypeOrReport::Type(ModuleType::Assembly);
-    }
     let mod_patterns = [
-        ("con", ":_module-type: CONCEPT", ModuleType::Concept),
-        ("proc", ":_module-type: PROCEDURE", ModuleType::Procedure),
-        ("ref", ":_module-type: REFERENCE", ModuleType::Reference),
+        ("assembly", ":_content-type: ASSEMBLY", ModuleType::Assembly),
+        ("con", ":_content-type: CONCEPT", ModuleType::Concept),
+        ("proc", ":_content-type: PROCEDURE", ModuleType::Procedure),
+        ("ref", ":_content-type: REFERENCE", ModuleType::Reference),
     ];
-    for pattern in mod_patterns.iter() {
+    for pattern in &mod_patterns {
         if base_name.starts_with(pattern.0) || content.contains(pattern.1) {
             return ModTypeOrReport::Type(pattern.2);
         }
@@ -174,8 +182,7 @@ fn determine_mod_type(base_name: &str, content: &str) -> ModTypeOrReport {
 fn perform_simple_tests(content: &str, tests: &[IssueDefinition]) -> Vec<IssueReport> {
     tests
         .iter()
-        .map(|&definition| definition.check(content))
-        .flatten()
+        .flat_map(|&definition| definition.check(content))
         .collect()
 }
 
@@ -301,6 +308,7 @@ mod title {
 // This section groups all content requirements
 mod content {
     use crate::validation::find_first_occurrence;
+    use crate::validation::find_mod_id;
     use crate::validation::perform_simple_tests;
     use crate::validation::IssueDefinition;
     use crate::validation::IssueReport;
@@ -336,9 +344,51 @@ mod content {
             reports.push(experimental_issue);
         }
 
+        reports.append(check_path_xrefs(content).as_mut());
+        reports.append(check_metadata_variable(content).as_mut());
+
         reports
     }
 
+    /// Check that the module type variable is located before the module ID, as required.
+    /// As a side effect, this function also checks that both the varible and the ID are present.
+    fn check_metadata_variable(content: &str) -> Vec<IssueReport> {
+        let metadata_var_pattern =
+            r":_content-type:\s*(?:ASSEMBLY|PROCEDURE|CONCEPT|REFERENCE|SNIPPET)";
+        let metadata_var_regex = Regex::new(metadata_var_pattern).unwrap();
+        let metadata_var = find_first_occurrence(content, metadata_var_regex);
+
+        let mod_id = find_mod_id(content);
+
+        // Prepare to store the reports about the module
+        let mut results: Vec<IssueReport> = Vec::new();
+
+        // Report if the metadata variable is completely missing.
+        // A missing ID is already reported elsewhere.
+        if metadata_var.is_none() {
+            let report = IssueReport {
+                line_number: None,
+                description: "The module is missing the _content-type attribute.",
+                severity: IssueSeverity::Warning,
+            };
+            results.push(report);
+        }
+
+        // If both elements are present, ensure their proper position in relation to each other
+        if let (Some(mod_id), Some(metadata_var)) = (mod_id, metadata_var) {
+            if mod_id.0 < metadata_var.0 {
+                let report = IssueReport {
+                    line_number: Some(metadata_var.0),
+                    description: "The _content-type attribute is located after the module ID.",
+                    severity: IssueSeverity::Error,
+                };
+                results.push(report);
+            }
+        }
+
+        results
+    }
+
     /// Check that the abstract flag exists in the file and that it's followed by a paragraph.
     fn check_abstract_flag(content: &str) -> Option<IssueReport> {
         let abstract_regex = Regex::new(r#"^\[role="_abstract"\]"#).unwrap();
@@ -408,14 +458,44 @@ mod content {
             None
         }
     }
+
+    /// Check that supported xrefs are path-based.
+    /// Report issues as warnings because ID-based xrefs might still work in some instances, such as within the file.
+    fn check_path_xrefs(content: &str) -> Vec<IssueReport> {
+        // Check only those xrefs that have labels. Skip unsupported, label-less xrefs, which are reported elsewhere.
+        let xref_regex = Regex::new(r"xref:(\S+)\[\S+.*?\]").unwrap();
+        // This regex checks only the captured content of the xref.
+        let path_based_regex = Regex::new(r"\S+\.(?:adoc|asciidoc)$").unwrap();
+
+        let mut issues = Vec::new();
+
+        for (index, line) in content.lines().enumerate() {
+            if let Some(xref) = xref_regex.captures(line) {
+                if path_based_regex.is_match(
+                    xref.get(1)
+                        .expect("Cannot capture the xref content.")
+                        .as_str(),
+                ) {
+                    // This xref is path-based. This is the correct form. Skip.
+                } else {
+                    // This xref is not path-based. Report.
+                    issues.push(IssueReport {
+                        line_number: Some(index),
+                        description: "This xref does not appear to be path-based. Make sure that it works in your assembly.",
+                        severity: IssueSeverity::Warning,
+                    });
+                }
+            }
+        }
+
+        issues
+    }
 }
 
 // This section groups all module requirements;
 // they depend on title and content, and additional resources requirements
 mod module {
     use crate::validation::check_common;
-    use crate::validation::find_first_occurrence;
-    use crate::validation::find_mod_id;
     use crate::validation::perform_simple_tests;
     use crate::validation::IssueDefinition;
     use crate::validation::IssueReport;
@@ -444,50 +524,11 @@ mod module {
 
         reports.append(check_common(content).as_mut());
         reports.append(perform_simple_tests(content, &SIMPLE_MODULE_TESTS).as_mut());
-        reports.append(check_metadata_variable(content).as_mut());
         reports.append(check_include_except_snip(content).as_mut());
 
         reports
     }
 
-    /// Check that the module type variable is located before the module ID, as required.
-    /// As a side effect, this function also checks that both the varible and the ID are present.
-    fn check_metadata_variable(content: &str) -> Vec<IssueReport> {
-        let metadata_var_pattern = r":_module-type:\s*(?:PROCEDURE|CONCEPT|REFERENCE)";
-        let metadata_var_regex = Regex::new(metadata_var_pattern).unwrap();
-        let metadata_var = find_first_occurrence(content, metadata_var_regex);
-
-        let mod_id = find_mod_id(content);
-
-        // Prepare to store the reports about the module
-        let mut results: Vec<IssueReport> = Vec::new();
-
-        // Report if the metadata variable is completely missing.
-        // A missing ID is already reported elsewhere.
-        if metadata_var.is_none() {
-            let report = IssueReport {
-                line_number: None,
-                description: "The module is missing the module type variable.",
-                severity: IssueSeverity::Warning,
-            };
-            results.push(report);
-        }
-
-        // If both elements are present, ensure their proper position in relation to each other
-        if let (Some(mod_id), Some(metadata_var)) = (mod_id, metadata_var) {
-            if mod_id.0 < metadata_var.0 {
-                let report = IssueReport {
-                    line_number: Some(metadata_var.0),
-                    description: "The module type variable is located after the module ID.",
-                    severity: IssueSeverity::Error,
-                };
-                results.push(report);
-            }
-        }
-
-        results
-    }
-
     /// Test that modules include no other modules, except for snippets
     fn check_include_except_snip(content: &str) -> Vec<IssueReport> {
         let any_include_pattern = r"^include::.*\.adoc";
